pub enum SinkResult {
Complete(Vec<Frame>),
MidFrame,
}Expand description
The result of feeding bytes to Decoder::sink.
Variants
Complete(Vec<Frame>)
All bytes were consumed and every frame found is complete. Contains the decoded frames.
MidFrame
The last frame in the supplied bytes is incomplete. The decoder has buffered the partial state; supply more bytes to finish it.